==> OOo_2.0.0_Win32Intel_solver_curvirgo_other.zip: solver/680/wntmsci10.pro/inc/com/sun/star/task/MasterPasswordRequest.hpp <==
#ifndef _COM_SUN_STAR_TASK_MASTERPASSWORDREQUEST_HPP_
#define _COM_SUN_STAR_TASK_MASTERPASSWORDREQUEST_HPP_

#ifndef _SAL_CONFIG_H_
#include "sal/config.h"
#endif

#ifndef _COM_SUN_STAR_TASK_MASTERPASSWORDREQUEST_HDL_
#include "com/sun/star/task/MasterPasswordRequest.hdl"
#endif

#ifndef _COM_SUN_STAR_TASK_PASSWORDREQUEST_HPP_
#include "com/sun/star/task/PasswordRequest.hpp"
#endif
#ifndef _COM_SUN_STAR_UNO_TYPE_HXX_
#include "com/sun/star/uno/Type.hxx"
#endif
#ifndef _OSL_MUTEX_HXX_
#include "osl/mutex.hxx"
#endif

namespace com { namespace sun { namespace star { namespace task {

inline MasterPasswordRequest::MasterPasswordRequest() SAL_THROW( () )
    : ::com::sun::star::task::PasswordRequest()
{ }

inline MasterPasswordRequest::MasterPasswordRequest(const ::rtl::OUString& Message_, const ::com::sun::star::uno::Reference< ::com::sun::star::uno::XInterface >& Context_, const ::com::sun::star::task::InteractionClassification& Classification_, const ::com::sun::star::task::PasswordRequestMode& Mode_) SAL_THROW( () )
    : ::com::sun::star::task::PasswordRequest(Message_, Context_, Classification_, Mode_)
{ }

MasterPasswordRequest::MasterPasswordRequest(MasterPasswordRequest const & the_other): ::com::sun::star::task::PasswordRequest(the_other) {}

MasterPasswordRequest::~MasterPasswordRequest() {}

MasterPasswordRequest & MasterPasswordRequest::operator =(MasterPasswordRequest const & the_other) {
    //TODO: Just like its implicitly-defined counterpart, this function definition is not exception-safe
    ::com::sun::star::task::PasswordRequest::operator =(the_other);
    return *this;
}

} } } }

inline const ::com::sun::star::uno::Type& SAL_CALL getCppuType( const ::com::sun::star::task::MasterPasswordRequest* ) SAL_THROW( () )
{
    static typelib_TypeDescriptionReference * the_type = 0;
    if ( !the_type )
    {
        typelib_static_type_init( &the_type, typelib_TypeClass_EXCEPTION, "com.sun.star.task.MasterPasswordRequest" );
    }
    return * reinterpret_cast< ::com::sun::star::uno::Type * >( &the_type );
}

#endif // _COM_SUN_STAR_TASK_MASTERPASSWORDREQUEST_HPP_

==> OOo_2.0.3_Win32Intel_solver_curvirgo_other.zip: solver/680/wntmsci10.pro/inc/com/sun/star/task/MasterPasswordRequest.hpp <==
#ifndef _COM_SUN_STAR_TASK_MASTERPASSWORDREQUEST_HPP_
#define _COM_SUN_STAR_TASK_MASTERPASSWORDREQUEST_HPP_

#ifndef _SAL_CONFIG_H_
#include "sal/config.h"
#endif

#ifndef _COM_SUN_STAR_TASK_MASTERPASSWORDREQUEST_HDL_
#include "com/sun/star/task/MasterPasswordRequest.hdl"
#endif

#ifndef _COM_SUN_STAR_TASK_PASSWORDREQUEST_HPP_
#include "com/sun/star/task/PasswordRequest.hpp"
#endif
#ifndef _COM_SUN_STAR_UNO_TYPE_HXX_
#include "com/sun/star/uno/Type.hxx"
#endif
#ifndef INCLUDED_CPPU_UNOTYPE_HXX
#include "cppu/unotype.hxx"
#endif
#ifndef _OSL_MUTEX_HXX_
#include "osl/mutex.hxx"
#endif

namespace com { namespace sun { namespace star { namespace task {

inline MasterPasswordRequest::MasterPasswordRequest() SAL_THROW( () )
    : ::com::sun::star::task::PasswordRequest()
{ }

inline MasterPasswordRequest::MasterPasswordRequest(const ::rtl::OUString& Message_, const ::com::sun::star::uno::Reference< ::com::sun::star::uno::XInterface >& Context_, const ::com::sun::star::task::InteractionClassification& Classification_, const ::com::sun::star::task::PasswordRequestMode& Mode_) SAL_THROW( () )
    : ::com::sun::star::task::PasswordRequest(Message_, Context_, Classification_, Mode_)
{ }

MasterPasswordRequest::MasterPasswordRequest(MasterPasswordRequest const & the_other): ::com::sun::star::task::PasswordRequest(the_other) {}

MasterPasswordRequest::~MasterPasswordRequest() {}

MasterPasswordRequest & MasterPasswordRequest::operator =(MasterPasswordRequest const & the_other) {
    //TODO: Just like its implicitly-defined counterpart, this function definition is not exception-safe
    ::com::sun::star::task::PasswordRequest::operator =(the_other);
    return *this;
}

} } } }

namespace com { namespace sun { namespace star { namespace task {

inline ::com::sun::star::uno::Type const & cppu_detail_getUnoType(::com::sun::star::task::MasterPasswordRequest const *) {
    static typelib_TypeDescriptionReference * the_type = 0;
    if ( !the_type )
    {
        typelib_static_type_init( &the_type, typelib_TypeClass_EXCEPTION, "com.sun.star.task.MasterPasswordRequest" );
    }
    return * reinterpret_cast< ::com::sun::star::uno::Type * >( &the_type );
};

} } } }

inline ::com::sun::star::uno::Type const & SAL_CALL getCppuType(::com::sun::star::task::MasterPasswordRequest const *) SAL_THROW(()) {
    return ::cppu::UnoType< ::com::sun::star::task::MasterPasswordRequest >::get();
}

#endif // _COM_SUN_STAR_TASK_MASTERPASSWORDREQUEST_HPP_
